==> js-2.0.tar.gz: js-2.0/_sym2sym.h <==
/*
 * Copyright (c) 2007, to-do. All rights reserved.
 */
case K_var: return K_var;
case K_M_1_PI: return K_M_1_PI;
case K_unquote: return K_unquote;
case K_abs: return K_abs;
case K_round: return K_round;
case K_isinf: return K_isinf;
case K_case: return K_case;
case K_isBool: return K_isBool;
case K_close: return K_close;
case K_values: return K_values;
case K_toChar: return K_toChar;
case K_continue: return K_continue;
case K_reverse: return K_reverse;
case K_readfile: return K_readfile;
case K_M_SQRT2: return K_M_SQRT2;
case K_isObject: return K_isObject;
case K_while: return K_while;
case K_touch: return K_touch;
case K_break: return K_break;
case K_match: return K_match;
case K_replace: return K_replace;
case K_NAN: return K_NAN;
case K_getcwd: return K_getcwd;
case K_M_PI_2: return K_M_PI_2;
case K_index: return K_index;
case K_isNull: return K_isNull;
case K_M_PI_4: return K_M_PI_4;
case K_isArray: return K_isArray;
case K_fatime: return K_fatime;
case K_crypt: return K_crypt;
case K_unlink: return K_unlink;
case K_asin: return K_asin;
case K_printf: return K_printf;
case K_remove: return K_remove;
case K_label: return K_label;
case K_M_2_SQRTPI: return K_M_2_SQRTPI;
case K_exit: return K_exit;
case K_length: return K_length;
case K_sprintf: return K_sprintf;
case K_print: return K_print;
case K_tan: return K_tan;
case K_isChar: return K_isChar;
case K_throw: return K_throw;
case K_false: return K_false;
case K_isnan: return K_isnan;
case K_ceil: return K_ceil;
case K_switch: return K_switch;
case K_null: return K_null;
case K_gmtime: return K_gmtime;
case K_shift: return K_shift;
case K_substr: return K_substr;
case K_toFloat: return K_toFloat;
case K_fgid: return K_fgid;
case K_tmpfile: return K_tmpfile;
case K_eval: return K_eval;
case K_trim: return K_trim;
case K_rename: return K_rename;
case K_atan2: return K_atan2;
case K_time: return K_time;
case K_return: return K_return;
case K_floor: return K_floor;
case K_if: return K_if;
case K_fmtime: return K_fmtime;
case K_popen: return K_popen;
case K_sqrt: return K_sqrt;
case K_in: return K_in;
case K_splice: return K_splice;
case K_mkdir: return K_mkdir;
case K_catch: return K_catch;
case K_jconv: return K_jconv;
case K_chdir: return K_chdir;
case K_rewind: return K_rewind;
case K_new: return K_new;
case K_isfinite: return K_isfinite;
case K_exp: return K_exp;
case K_M_LOG10E: return K_M_LOG10E;
case K_dbopen: return K_dbopen;
case K_unshift: return K_unshift;
case K_foreach: return K_foreach;
case K_M_LN2: return K_M_LN2;
case K_this: return K_this;
case K_tempnam: return K_tempnam;
case K_atan: return K_atan;
case K_join: return K_join;
case K_try: return K_try;
case K_cos: return K_cos;
case K_symlink: return K_symlink;
case K_chown: return K_chown;
case K_pop: return K_pop;
case K_decode: return K_decode;
case K_max: return K_max;
case K_keys: return K_keys;
case K_pow: return K_pow;
case K_setenv: return K_setenv;
case K_min: return K_min;
case K_rindex: return K_rindex;
case K_toInt: return K_toInt;
case K_fmode: return K_fmode;
case K_sort: return K_sort;
case K_fcopy: return K_fcopy;
case K_isString: return K_isString;
case K_M_PI: return K_M_PI;
case K_printfile: return K_printfile;
case K_void: return K_void;
case K_chmod: return K_chmod;
case K_read: return K_read;
case K_trace: return K_trace;
case K_class: return K_class;
case K_pclose: return K_pclose;
case K_for: return K_for;
case K_unpack: return K_unpack;
case K_md5: return K_md5;
case K_log10: return K_log10;
case K_goto: return K_goto;
case K_delete: return K_delete;
case K_tell: return K_tell;
case K_fctime: return K_fctime;
case K_M_E: return K_M_E;
case K_fopen: return K_fopen;
case K_isInt: return K_isInt;
case K_function: return K_function;
case K_isFloat: return K_isFloat;
case K_fuid: return K_fuid;
case K_isNumber: return K_isNumber;
case K_println: return K_println;
case K_push: return K_push;
case K_do: return K_do;
case K_writefile: return K_writefile;
case K_unserial: return K_unserial;
case K_INFINITY: return K_INFINITY;
case K_system: return K_system;
case K_getc: return K_getc;
case K_M_2_PI: return K_M_2_PI;
case K_getenv: return K_getenv;
case K_acos: return K_acos;
case K_glob: return K_glob;
case K_fsize: return K_fsize;
case K_serial: return K_serial;
case K_else: return K_else;
case K_gets: return K_gets;
case K_quote: return K_quote;
case K_write: return K_write;
case K_toBool: return K_toBool;
case K_putc: return K_putc;
case K_untrace: return K_untrace;
case K_rand: return K_rand;
case K_M_SQRT1_2: return K_M_SQRT1_2;
case K_typeof: return K_typeof;
case K_encode: return K_encode;
case K_gmdate: return K_gmdate;
case K_default: return K_default;
case K_toString: return K_toString;
case K___LINE__: return K___LINE__;
case K_flink: return K_flink;
case K_pack: return K_pack;
case K_M_LN10: return K_M_LN10;
case K_sin: return K_sin;
case K_true: return K_true;
case K_echo: return K_echo;
case K_puts: return K_puts;
case K_date: return K_date;
case K_load: return K_load;
case K___FILE__: return K___FILE__;
case K_log: return K_log;
case K_toNumber: return K_toNumber;
case K_truncate: return K_truncate;
case K_split: return K_split;
case K_M_LOG2E: return K_M_LOG2E;
case K_seek: return K_seek;

==> js3.0.1.tar.gz: js3.0.1/_sym2sym.h <==
/*
 * Copyright (c) 2007, to-do. All rights reserved.
 */
case K_var: return K_var;
case K_M_1_PI: return K_M_1_PI;
case K_unquote: return K_unquote;
case K_abs: return K_abs;
case K_round: return K_round;
case K_isinf: return K_isinf;
case K_case: return K_case;
case K_isBool: return K_isBool;
case K_close: return K_close;
case K_values: return K_values;
case K_count: return K_count;
case K_toChar: return K_toChar;
case K_continue: return K_continue;
case K_reverse: return K_reverse;
case K_readfile: return K_readfile;
case K_M_SQRT2: return K_M_SQRT2;
case K_while: return K_while;
case K_isObject: return K_isObject;
case K_modify: return K_modify;
case K_touch: return K_touch;
case K_break: return K_break;
case K_match: return K_match;
case K_replace: return K_replace;
case K_NAN: return K_NAN;
case K_getcwd: return K_getcwd;
case K_M_PI_2: return K_M_PI_2;
case K_index: return K_index;
case K_isNull: return K_isNull;
case K_mktime: return K_mktime;
case K_M_PI_4: return K_M_PI_4;
case K_isArray: return K_isArray;
case K_fatime: return K_fatime;
case K_stdout: return K_stdout;
case K_crypt: return K_crypt;
case K_printf: return K_printf;
case K_asin: return K_asin;
case K_unlink: return K_unlink;
case K_remove: return K_remove;
case K_label: return K_label;
case K_M_2_SQRTPI: return K_M_2_SQRTPI;
case K_exit: return K_exit;
case K_length: return K_length;
case K_sprintf: return K_sprintf;
case K_print: return K_print;
case K_tan: return K_tan;
case K_timegm: return K_timegm;
case K_repmatch: return K_repmatch;
case K_isChar: return K_isChar;
case K_throw: return K_throw;
case K_false: return K_false;
case K_isnan: return K_isnan;
case K_ceil: return K_ceil;
case K_switch: return K_switch;
case K_null: return K_null;
case K_shift: return K_shift;
case K_substr: return K_substr;
case K_fetch: return K_fetch;
case K_toFloat: return K_toFloat;
case K_fgid: return K_fgid;
case K_tmpfile: return K_tmpfile;
case K_eval: return K_eval;
case K_trim: return K_trim;
case K_rename: return K_rename;
case K_atan2: return K_atan2;
case K_time: return K_time;
case K_return: return K_return;
case K_floor: return K_floor;
case K_if: return K_if;
case K_tracef: return K_tracef;
case K_fmtime: return K_fmtime;
case K_sqrt: return K_sqrt;
case K_popen: return K_popen;
case K_in: return K_in;
case K_splice: return K_splice;
case K_mkdir: return K_mkdir;
case K_catch: return K_catch;
case K_jconv: return K_jconv;
case K_chdir: return K_chdir;
case K_traces: return K_traces;
case K_rewind: return K_rewind;
case K_new: return K_new;
case K_isfinite: return K_isfinite;
case K_exp: return K_exp;
case K_M_LOG10E: return K_M_LOG10E;
case K_dbopen: return K_dbopen;
case K_unshift: return K_unshift;
case K_foreach: return K_foreach;
case K_M_LN2: return K_M_LN2;
case K_sum: return K_sum;
case K_this: return K_this;
case K_tempnam: return K_tempnam;
case K_atan: return K_atan;
case K_join: return K_join;
case K_try: return K_try;
case K_cos: return K_cos;
case K_symlink: return K_symlink;
case K_chown: return K_chown;
case K_pop: return K_pop;
case K_decode: return K_decode;
case K_max: return K_max;
case K_keys: return K_keys;
case K_xmlopen: return K_xmlopen;
case K_pow: return K_pow;
case K_setenv: return K_setenv;
case K_min: return K_min;
case K_rindex: return K_rindex;
case K_toInt: return K_toInt;
case K_fmode: return K_fmode;
case K_sort: return K_sort;
case K_fcopy: return K_fcopy;
case K_isString: return K_isString;
case K_M_PI: return K_M_PI;
case K_printfile: return K_printfile;
case K_void: return K_void;
case K_chmod: return K_chmod;
case K_read: return K_read;
case K_trace: return K_trace;
case K_class: return K_class;
case K_pclose: return K_pclose;
case K_for: return K_for;
case K_unpack: return K_unpack;
case K_md5: return K_md5;
case K_log10: return K_log10;
case K_goto: return K_goto;
case K_delete: return K_delete;
case K_tell: return K_tell;
case K_fctime: return K_fctime;
case K_M_E: return K_M_E;
case K_fopen: return K_fopen;
case K_isInt: return K_isInt;
case K_unentity: return K_unentity;
case K_isFloat: return K_isFloat;
case K_function: return K_function;
case K_isNumber: return K_isNumber;
case K_fuid: return K_fuid;
case K_push: return K_push;
case K_println: return K_println;
case K_writefile: return K_writefile;
case K_do: return K_do;
case K_unserial: return K_unserial;
case K_INFINITY: return K_INFINITY;
case K_system: return K_system;
case K_getc: return K_getc;
case K_entity: return K_entity;
case K_M_2_PI: return K_M_2_PI;
case K_getenv: return K_getenv;
case K_acos: return K_acos;
case K_glob: return K_glob;
case K_fsize: return K_fsize;
case K_serial: return K_serial;
case K_else: return K_else;
case K_gets: return K_gets;
case K_quote: return K_quote;
case K_write: return K_write;
case K_toBool: return K_toBool;
case K_putc: return K_putc;
case K_rand: return K_rand;
case K_untrace: return K_untrace;
case K_M_SQRT1_2: return K_M_SQRT1_2;
case K_formatf: return K_formatf;
case K_typeof: return K_typeof;
case K_encode: return K_encode;
case K_gmdate: return K_gmdate;
case K_default: return K_default;
case K_toString: return K_toString;
case K_stderr: return K_stderr;
case K___LINE__: return K___LINE__;
case K_flink: return K_flink;
case K_pack: return K_pack;
case K_M_LN10: return K_M_LN10;
case K_sin: return K_sin;
case K_true: return K_true;
case K_formats: return K_formats;
case K_echo: return K_echo;
case K_puts: return K_puts;
case K_date: return K_date;
case K_stdin: return K_stdin;
case K_load: return K_load;
case K___FILE__: return K___FILE__;
case K_log: return K_log;
case K_toNumber: return K_toNumber;
case K_select: return K_select;
case K_truncate: return K_truncate;
case K_split: return K_split;
case K_M_LOG2E: return K_M_LOG2E;
case K_seek: return K_seek;
